#
# spec file for package sops
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) specCURRENT_YEAR SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           sops
Version:        3.9.0
Release:        1.1
Summary:        Simple and flexible tool for managing secrets
License:        MPL-2.0
Group:          Productivity/Security
URL:            https://github.com/getsops/sops
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang-packaging
BuildRequires:  xz
BuildRequires:  golang(API) >= 1.15

%description
Simple and flexible tool for managing secrets

%prep
%setup -q
%setup -q -T -D -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -o bin/sops ./cmd/sops/

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%license LICENSE
%doc CHANGELOG.rst README.rst
%{_bindir}/%{name}

%changelog
* Wed Jul  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.9.0:
  * Respect aws_profile from Keygroup Config by @Kouzukii in #1049
  * build(deps): Bump the go group with 6 updates by @dependabot in
    [#1327]
  * build(deps): Bump the go group with 3 updates by @dependabot in
    [#1328]
  * build(deps): Bump the go group with 1 update by @dependabot in
    [#1330]
  * build(deps): Bump github.com/docker/docker from
    20.10.24+incompatible to 24.0.7+incompatible by @dependabot in
    [#1336]
  * build(deps): Bump the go group with 3 updates by @dependabot in
    [#1334]
  * Improve README.rst by @Ph0tonic in #1339
  * Fix typos by @felixfontein in #1337
  * build(deps): Bump the go group with 7 updates by @dependabot in
    [#1344]
  * Add --mac-only-encrypted to compute MAC only over values which
    end up encrypted by @mitar in #973
  * build(deps): Bump the ci group with 1 update by @dependabot in
    [#1347]
  * build(deps): Bump the go group with 7 updates by @dependabot in
    [#1348]
  * README: Correctly tag code as yaml-stream by @felixfontein in
    [#1350]
  * build(deps): Bump the go group with 5 updates by @dependabot in
    [#1354]
  * use getUserConfigDir also in tests by @bkreitch in #1346
  * Overwrite home dir in vault test by @bkreitch in #1349
  * Allow configuration of indentation for YAML and JSON stores by
    @Ph0tonic in #1273
  * build(deps): Bump github.com/go-jose/go-jose/v3 from 3.0.0 to
    3.0.1 by @dependabot in #1357
  * build(deps): Bump the go group with 4 updates by @dependabot in
    [#1360]
  * build(deps): Bump the ci group with 1 update by @dependabot in
    [#1359]
  * Fix TestGnuPGHome_Validate by @stormentt in #1370
  * build(deps): Bump the go group with 6 updates by @dependabot in
    [#1373]
  * build(deps): Bump the ci group with 2 updates by @dependabot in
    [#1376]
  * Docs: indent is used both for encryption and decryption by
    @felixfontein in #1372
  * fix a bug where not having a config results in a panic by
    @stormentt in #1371
  * Polish the 'sops help' output a bit by @felixfontein in #1341
  * introduce a --pristine flag to sops exec-env by @e-nikolov in
    [#912]
  * Allow to pass multiple paths to 'updatekeys' by @sj14 in #1274
  * Warn/fail if the wrong number of arguments is provided by
    @felixfontein in #1342
  * Allow to override fileName with different value by
    @felixfontein in #1332
  * Sort masterkeys according to decryption-order by @bkreitch in
    [#1345]
  * build(deps): Bump the ci group with 4 updates by @dependabot in
    [#1382]
  * build(deps): Bump the go group with 5 updates by @dependabot in
    [#1381]
  * Deprecate the --background option to exec-env and exec-file by
    @felixfontein in #1379
  * build(deps): Bump golang.org/x/crypto from 0.16.0 to 0.17.0 by
    @dependabot in #1383
  * build(deps): Bump the ci group with 1 update by @dependabot in
    [#1386]
  * build(deps): Bump the go group with 5 updates by @dependabot in
    [#1385]
  * Consolidate Flatten/Unflatten pre/post processing by
    @lancerushing in #1356
  * INI, DotEnv stores: shamir_threshold is an integer by
    @felixfontein in #1394
  * Improve integration tests: reformat test code, make sure exit
    codes are always checked by @felixfontein in #1390
  * Make check whether file contains invalid keys for encryption
    dependent on output store by @felixfontein in #1393
  * Create a constant for the 'sops' metadata key by @felixfontein
    in #1398
  * build(deps): Bump github.com/cloudflare/circl from 1.3.3 to
    1.3.7 by @dependabot in #1408
  * build(deps): Bump the ci group with 4 updates by @dependabot in
    [#1425]
  * build(deps): Bump github.com/opencontainers/runc from 1.1.5 to
    1.1.12 by @dependabot in #1428
  * build(deps): Bump the go group with 10 updates by @dependabot
    in #1429
  * build(deps): Bump the ci group with 4 updates by @dependabot in
    [#1432]
  * Warn if more than one command is used by @felixfontein in #1388
  * Move extraction of encryption and rotation options to separate
    functions by @felixfontein in #1389
  * Add separate subcommands for encryption, decryption, rotating,
    editing, and setting values by @felixfontein in #1391
  * Add basic tests for exec-env and exec-file by @felixfontein in
    [#1396]
  * build with go 1.21 and update dependencies by @b-dean in #1427
  * build(deps): Bump the go group with 4 updates by @dependabot in
    [#1439]
  * sops: fix typo in interface name by @duthils in #1477
  * Fix function name in comment by @pullmerge in #1484
  * build(deps): Bump the ci group across 1 directory with 9
    updates by @dependabot in #1498
  * build(deps): Bump github.com/go-jose/go-jose/v3 from 3.0.1 to
    3.0.3 by @dependabot in #1454
  * build(deps): Bump google.golang.org/protobuf from 1.32.0 to
    1.33.0 by @dependabot in #1460
  * build(deps): Bump github.com/docker/docker from
    24.0.7+incompatible to 24.0.9+incompatible by @dependabot in
  [#1466]
  * build(deps): Bump golang.org/x/net from 0.21.0 to 0.23.0 by
    @dependabot in #1489
  * build(deps): Bump actions/setup-go from 5.0.0 to 5.0.1 in the
    ci group by @dependabot in #1503
  * build(deps): Bump the ci group with 2 updates by @dependabot in
    [#1508]
  * LoadCreationRuleForFile: correctly handle nil without error in
    callers by @felixfontein in #1506
  * build(deps): Bump the ci group with 2 updates by @dependabot in
    [#1510]
  * build(deps): Bump the ci group with 2 updates by @dependabot in
    [#1516]
  * Fix CVE-2024-2660 by @TheoBrigitte in #1519
  * build(deps): Bump the ci group with 2 updates by @dependabot in
    [#1521]
  * fix(Makefile): set locale to make tests pass by
    @jonasbadstuebner in #1492
  * build(deps): Bump the ci group with 2 updates by @dependabot in
    [#1524]
  * Adjust Makefile to new goreleaser 6.0.0 release by
    @felixfontein in #1526
  * build(deps): Bump the go group across 1 directory with 23
    updates by @dependabot in #1525
  * update documentation for age by @tomaszduda23 in #1399
  * exec-file: if --filename is used, use the provided filename
    without random suffix by @felixfontein in #1474
  * build(deps): Bump
    github.com/Azure/azure-sdk-for-go/sdk/azidentity from 1.5.2 to
    1.6.0 by @dependabot in #1528
  * Do not use DotEnv store for exec-env, but specialized
    environment serializing code by @felixfontein in #1436
  * build(deps): Bump the ci group with 2 updates by @dependabot in
    [#1534]
  * Decryption: do not fail if no matching creation_rule is present
    in config file by @felixfontein in #1434
  * add filestatus command by @endorama in #545
  * build(deps): Bump the go group across 1 directory with 16
    updates by @dependabot in #1540
  * build(deps): Bump the go group across 1 directory with 4
    updates by @dependabot in #1543
  * add command unset by @duthils in #1475
  * Update sops.go comment by @rjeczkow in #1544
  * Support using comments to select parts to encrypt by
    @felixfontein in #1392
  * Feature: merge key for key groups and make keys unique by
    @jonasbadstuebner in #1493
  * Update all go deps by @felixfontein in #1545
  * Release 3.9.0 by @felixfontein in #1546
* Thu Oct 12 2023 kastl@b1-systems.de
- Update to version 3.8.1:
  * Release v3.8.1
  * Update dependencies
  * Add section in CONTRIBUTING.md on docs changes.
  * Add checkdocs, checkrst, and checkmd make targets.
  * Add workflow for rstcheck and mdl.
  * Change some SOPSs back to sops.
  * Normalize SOPS usages.
  * Normalize indentation for code blocks and YAML files.
  * Improve MD files (with mdl feedback).
  * Improve RST files (with rstcheck feedback).
  * pgp: further improve import error format
  * pgp: better error reporting for missing GPG binary
  * docs: document AWS environment variables
  * build(deps): Bump the go group with 7 updates
  * Make sure to wrap raw errors with toExitError().
  * Report key rotation errors.
  * Check err for nil in tests.
  * Defer only after checking err.
  * Handle unhandled errors.
  * Ignore irrelevant return value (it is always nil).
  * decrypt: fix dropped error
  * pgp: do not require abs path for SopsGpgExecEnv
  * Make error the last return value
  * Handle return values of dec.Token() to improve error messages.
  * Fix versions in comments
  * build(deps): Bump the ci group with 1 update
  * build(deps): Bump the go group with 4 updates
  * Fix descriptions of unencrypted-regex and encrypted-regex
    flags.
  * Reject completely empty documents.
  * On macOS, prefer XDG_CONFIG_HOME over os.UserConfigDir()
  * Improve handling of errors when binary store handles bad data
  * Delete sops encrypted file we don't have keys for.
  * pgp: remove `--no-default-keyring` argument
  * pgp: improve handling of GnuPG home dir
  * build(deps): Bump the ci group with 3 updates
* Wed Oct  4 2023 Johannes Kastl <kastl@b1-systems.de>
- fix broken sops executable (sorry...)
* Mon Sep 25 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 3.8.0:
  * Features:
  - Support --version without network requests using
  - -disable-version-check (#1115)
  - Support --input-type for updatekeys command (#1116)
  * Improvements:
  - pgp: modernize and improve, and add tests (#1054, #1282)
  - azkv: update SDK to latest, add tests, tidy (#1067, #1092,
    [#1256])
  - age: improve identity loading, add tests, tidy (#1064)
  - kms: AWS SDK V2, allow creds config, add tests (#1065, #1257)
  - gcpkms: update SDK to latest, add tests, tidy (#1072, #1255)
  - hcvault: update API, add tests, tidy (#1085)
  - Do not report version when upstream --version check fails
    (#1124)
  - Use GitHub endpoints in --version command (#1261)
  - Close temporary file before invoking editor to widen support
    on Windows (#1265)
  - Update dependencies (#1063, #1091, #1147, #1242, #1260,
    [#1264], #1275, #1280, #1283)
  - Deal with various deprecations of dependencies (#1113, #1262)
  * Bug fixes:
  - Ensure YAML comments are not displaced (#1069)
  - Ensure default Google credentials can be used again after
    introduction of GOOGLE_CREDENTIALS (#1249)
  - Avoid duplicate logging of errors in some key sources (#1146,
    [#1281])
  - Using --set on a root level key does no longer truncate
    existing values (#899)
  - Ensure stable order of SOPS parameters in dotenv file (#1101)
  * Project changes:
  - Update Go to 1.20 (#1148)
  - Update rustc functional tests to v1.70.0 (#1234)
  - Remove remaining CircleCI workflow (#1237)
  - Run CLI workflow on main (#1243)
  - Delete obsolete validation/ artifact (#1248)
  - Rename Go module to github.com/getsops/sops/v3 (#1247)
  - Revamp release automation, including (Cosign) signed
    container images and checksums file, SLSA3 provenance and
    SBOMs (#1250)
  - Update various bits of documentation (#1244)
  - Add missing --encrypt flag from Vault example (#1060)
  - Add documentation on how to use age in .sops.yaml (#1192)
  - Improve Make targets and address various issues (#1258)
  - Ensure clean working tree in CI (#1267)
  - Fix CHANGELOG.rst formatting (#1269)
  - Pin GitHub Actions to full length commit SHA and add CodeQL
    (#1276)
  - Enable Dependabot for Docker, GitHub Actions and Go Mod
    (#1277)
  - Generate versioned .intoto.jsonl (#1278)
  - Update CI dependencies (#1279)
* Tue May 24 2022 rombert@apache.org
- Update to version 3.7.3:
  * prep for v3.7.3
  * Use custom GOOGLE_CREDENTIALS or fallback to default
  * Replace x/crypto/openpgp with ProtonMail/go-crypto
  * Update remaining dependencies
  * Update golang.org/x/{net,oauth2,sys} dependencies
  * Update keyservice implementation dependencies
  * Update golang.org/x/crypto
  * Limit role session name length to 64 characters.
  * keyservice: accept KeyServiceServer in LocalClient
  * Use latest dockerd in CI to allow build alpine image (#870)
  * Add tests for single key
  * Make `masterKeyFromRecipient` private
  * This fixes a bug with age encryption when specifying multiple age recipients
  * Explicitly build linux amd64 binary
  * Remove duplicated stage from Dockerfile.alpine
  * Upgrade all dependencies
  * Build alpine container in CI (#870)
  * Update keysource.go
  * support gcp credentials as env var
  * Allow empty maps for yaml (#907)
  * Add a test to reproduce #907
* Wed Mar 16 2022 rombert@apache.org
- Update to version 3.7.2:
  * Fixed CHANGELOG formatting
  * prep v3.7.2
  * Add arm64 .deb and .rpm builds
  * README and author tweaks
  * Change labeling and upload linux arm64
  * Move age environment variable names to constants
  * Support SOPS_AGE_KEY environment variable
  * Added support for go 1.16 and darwin-arm64
  * Tests should not fail fast
* Fri May  7 2021 Chris Coutinho <chrisbcoutinho@gmail.com>
- Initial commit
